@@ -1,6 +1,8 @@
 from ..session import sagemaker_session
 from .config import SageMakerTrainingConfig
 import os
+from aws_sagemaker_remote.util.json_read import json_urlparse, json_converter
+import json
 from sagemaker.pytorch import PyTorch
 from .channels import standardize_channels, upload_local_channels
 from sagemaker.utils import name_from_base
@@ -17,6 +19,7 @@ from urllib.parse import urlparse
 from ..util.pipes import chunk_iterable
 from sagemaker.s3 import S3Uploader
 from sagemaker.inputs import ShuffleConfig
+from aws_sagemaker_remote.ecr.images import ecr_ensure_image
 
 
 def sagemaker_training_run(
@@ -27,11 +30,18 @@ def sagemaker_training_run(
     if os.getenv('SM_TRAINING_ENV', None):
         warnings.warn(
             "Trying to start a SageMaker container from a SageMaker container. Possible loop detected.")
+
     if metrics is None:
         metrics = {}
     session = sagemaker_session(
         profile_name=args.sagemaker_profile
     )
+    image_uri = ecr_ensure_image(
+        path=args.sagemaker_training_image,
+        tag=args.sagemaker_training_image,
+        accounts=args.sagemaker_training_image.split(","),
+        session=session.boto_session
+    )
     script = args.sagemaker_script
     script = os.path.abspath(script)
     source = args.sagemaker_source
@@ -80,6 +90,7 @@ def sagemaker_training_run(
 
     channels = config.inputs
     channels = {k: getattr(args, k) for k in channels.keys()}
+    channels = {k: json_urlparse(v) for k, v in channels.items()}
     # and config.inputs[k].required == False}
     channels = {k: v for k, v in channels.items() if v}
     # for k,v in channels.items():
@@ -203,7 +214,7 @@ def sagemaker_training_run(
         source_dir=source,
         role=training_role,
         instance_type=args.sagemaker_training_instance,
-        image_uri=args.sagemaker_training_image,
+        image_uri=image_uri,
         instance_count=1,
         framework_version='1.5.0',
         # hyperparameters=hyperparameters_from_argparse(vars(args)),
@@ -235,7 +246,18 @@ def sagemaker_training_run(
         experiment_config = None
 
     estimator.fit(channels, job_name=job_name,
-                  wait=args.sagemaker_wait, experiment_config=experiment_config)
+                  wait=False, experiment_config=experiment_config)
+    job = estimator.latest_training_job
+    if args.output_json:
+        obj = job.describe()
+        #print("Describe: {}".format(obj))
+        os.makedirs(os.path.dirname(
+            os.path.abspath(args.output_json)), exist_ok=True)
+        with open(args.output_json, 'w') as f:
+            json.dump(obj, f, default=json_converter, indent=4)
+
+    if args.sagemaker_wait:
+        job.wait(logs=True)  # args.sagemaker_logs)
     # todo:
     # use_spot_instances
     # experiment_config (dict[str, str]): Experiment management configuration.
